@@ -1798,7 +1798,6 @@ static PyObject *ForthonPackage_printtypenum(PyObject *_self_,PyObject *args)
 #define _GNU_SOURCE 1
 #endif
 #include <fenv.h>
-#include <xmmintrin.h>
 #endif
 static char feenableexcept_doc[] = "Turns on or off trapping of floating point exceptions";
 static PyObject *ForthonPackage_feenableexcept(PyObject *_self_,PyObject *args)
@@ -1809,12 +1808,11 @@ static PyObject *ForthonPackage_feenableexcept(PyObject *_self_,PyObject *args)
 
 #ifdef WITH_FEENABLEEXCEPT
     if (flag) {
-      /* feenableexcept(FE_DIVBYZERO | FE_OVERFLOW | FE_INVALID); */
-      _MM_SET_EXCEPTION_MASK(_MM_GET_EXCEPTION_MASK() & ~_MM_MASK_INVALID);
+      feenableexcept(FE_DIVBYZERO | FE_OVERFLOW | FE_INVALID);
+    }
+    else {
+      fedisableexcept(FE_DIVBYZERO | FE_OVERFLOW | FE_INVALID);
     }
-    /* else { */
-      /* fedisableexcept(FE_DIVBYZERO | FE_OVERFLOW | FE_INVALID); */
-    /* } */
 #endif
 
   returnnone;
